@@ -199,7 +199,7 @@ class TestCommand(ArgumentCommand):
                 container.build()
                 print("{} built".format(container.tag))
             try:
-                container.test()
+                container.test(self.options.rebuild)
                 print("{} test succeeded".format(container.tag))
             except TestError as e:
                 print("{} test failed: exit code {}".format(container.tag, e.exit_code))
