@@ -176,9 +176,9 @@ class Container(object):
         self._testing = testing
 
         # some CI systems do not allow image removal
-        self.allow_image_remove = True
-        if os.getenv('CIRCLECI', '') == 'true':
-            self.allow_image_remove = False
+        self.allow_remove = True
+        if os.getenv('CIRCLECI', None):
+            self.allow_remove = False
 
     def to_dict(self, raw=False):
         """
@@ -392,7 +392,7 @@ class Container(object):
             self.prebuild()
 
         args = ['docker', 'build', '-t', self.tag]
-        if self.allow_image_remove:
+        if self.allow_remove:
             args += ['--rm', '--force-rm']
         if nocache:
             args.append('--no-cache')
@@ -452,7 +452,7 @@ class Container(object):
         except KeyboardInterrupt:
             pass
         finally:
-            if not detach:
+            if not detach and self.allow_remove:
                 args = self._get_fig_args('rm', '--force', '-v')
                 subprocess.call(args, cwd=self.path)
 
@@ -468,8 +468,9 @@ class Container(object):
         except subprocess.CalledProcessError:
             raise ContainerError("{} kill failed")
         finally:
-            args = self._get_fig_args('rm', '--force', '-v')
-            subprocess.call(args, cwd=self.path)
+            if self.allow_remove:
+                args = self._get_fig_args('rm', '--force', '-v')
+                subprocess.call(args, cwd=self.path)
 
     def test(self, rebuild=None):
         """
@@ -499,7 +500,10 @@ class Container(object):
             raise ContainerError("{} test failed: failed to start dependencies")
 
         try:
-            args = self._get_fig_args('run', '--rm', 'test')
+            if self.allow_remove:
+                args = self._get_fig_args('run', '--rm', 'test')
+            else:
+                args = self._get_fig_args('run', 'test')
             exit_code = subprocess.call(args, cwd=self.path)
             if exit_code != 0:
                 msg = "{} test failed: returned non-zero exit code {}"
